window.Gleam.initSearch([{"doc":"bigben","title":"bigben","content":"# bigben\n\n[![Package Version](https://img.shields.io/hexpm/v/bigben)](https://hex.pm/packages/bigben)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/bigben/)\n\n🕰️ A clock abstraction, with time travel.\n\n## Installation\n\n```sh\ngleam add bigben\n```\n\n## Usage\n\n```gleam\nimport bigben/clock.{type Clock}\nimport bigben/fake_clock\nimport birl\nimport birl/duration\nimport gleam/io\n\npub fn main() {\n  // In your production code, you&#39;ll use the real `Clock` to get the time\n  // from the system:\n  let clock = clock.new()\n  what_day_is_it(clock) // Today is Monday.\n\n  // In test code you can construct a `FakeClock`:\n  let assert Ok(now) = birl.parse(&quot;2024-04-08T02:26:31.464Z&quot;)\n  let fake_clock = fake_clock.new_at(now)\n  // and pass it off as a real `Clock`:\n  let clock = clock.from_fake(fake_clock)\n\n  what_day_is_it(clock) // Today is Monday.\n\n  // We can then manipulate the clock to help us in our tests:\n  fake_clock.advance(fake_clock, duration.days(4))\n\n  what_day_is_it(clock) // Today is Friday.\n}\n\nfn what_day_is_it(clock: Clock) {\n  let day_of_the_week =\n    clock\n    |&gt; clock.now\n    |&gt; birl.string_weekday\n\n  io.println(&quot;Today is &quot; &lt;&gt; day_of_the_week &lt;&gt; &quot;.&quot;)\n}\n```\n\n## Targets\n\n`bigben` supports the Erlang target.\n","url":"index.html"},{"doc":"bigben/fake_clock","title":"FakeClock","content":"pub opaque type FakeClock\n A fake clock.\n\nSynonyms:\nbigben/fake_clock.FakeClock\nbigben/fake_clock FakeClock","url":"bigben/fake_clock.html#FakeClock"},{"doc":"bigben/fake_clock","title":"advance","content":"pub fn advance(clock: FakeClock, duration: Duration) -&gt; Nil\n Advances the given `FakeClock` by the specified duration.\nSynonyms:\nbigben/fake_clock.advance\nbigben/fake_clock advance","url":"bigben/fake_clock.html#advance"},{"doc":"bigben/fake_clock","title":"new","content":"pub fn new() -&gt; FakeClock\n Returns a new `FakeClock`.\n\n The current time will be now in UTC.\nSynonyms:\nbigben/fake_clock.new\nbigben/fake_clock new","url":"bigben/fake_clock.html#new"},{"doc":"bigben/fake_clock","title":"new_at","content":"pub fn new_at(now: Time) -&gt; FakeClock\n Returns a new `FakeClock` at the given time.\nSynonyms:\nbigben/fake_clock.new_at\nbigben/fake_clock new_at","url":"bigben/fake_clock.html#new_at"},{"doc":"bigben/fake_clock","title":"now","content":"pub fn now(clock: FakeClock) -&gt; Time\n Returns the current time on the given `FakeClock`.\nSynonyms:\nbigben/fake_clock.now\nbigben/fake_clock now","url":"bigben/fake_clock.html#now"},{"doc":"bigben/fake_clock","title":"set_now","content":"pub fn set_now(clock: FakeClock, now: Time) -&gt; Nil\n Sets the current time on the given `FakeClock` to the specified value.\nSynonyms:\nbigben/fake_clock.set_now\nbigben/fake_clock set_now","url":"bigben/fake_clock.html#set_now"},{"doc":"bigben/fake_clock","title":"bigben/fake_clock","content":" A fake clock for manipulating the flow of time.","url":"bigben/fake_clock.html"},{"doc":"bigben/clock","title":"Clock","content":"pub opaque type Clock\n A clock.\n\nSynonyms:\nbigben/clock.Clock\nbigben/clock Clock","url":"bigben/clock.html#Clock"},{"doc":"bigben/clock","title":"from_fake","content":"pub fn from_fake(clock: FakeClock) -&gt; Clock\n Returns a new `Clock` constructed from the given `FakeClock`.\nSynonyms:\nbigben/clock.from_fake\nbigben/clock from_fake","url":"bigben/clock.html#from_fake"},{"doc":"bigben/clock","title":"new","content":"pub fn new() -&gt; Clock\n Returns a new `Clock`.\nSynonyms:\nbigben/clock.new\nbigben/clock new","url":"bigben/clock.html#new"},{"doc":"bigben/clock","title":"now","content":"pub fn now(clock: Clock) -&gt; Time\n Returns the current time on the given `Clock`, in UTC.\nSynonyms:\nbigben/clock.now\nbigben/clock now","url":"bigben/clock.html#now"},{"doc":"bigben/clock","title":"bigben/clock","content":" A clock.","url":"bigben/clock.html"}]);